package de.hottis.measurementCollector;

import de.hottis.common.MyQueue;
import de.hottis.smarthomelib.ADataObject;
import de.hottis.smarthomelib.TemperatureDataObject;
import java.time.LocalDateTime;
import java.util.Properties;

/**
 *
 * @author wn
 */
public class EspThermometerParser extends AMessageParser {

    static final String TOPIC = "IoT/espThermometer2/+/measurement";

    public EspThermometerParser(Properties config, MyQueue<ADataObject> queue) {
        super(TOPIC, config, queue);
    }

    @Override
    public void execute(LocalDateTime timestamp, String msgPayload) {
        try {
            // BueroBochum 22.93 2.486 1577
            String[] payloadParts = msgPayload.split(" ");
            if (payloadParts.length != 4) {
                throw new MeasurementCollectorException("invalid number of parts in message: " + msgPayload);
            }
            String name = payloadParts[0];
            double temperature = Double.parseDouble(payloadParts[1]);

            TemperatureDataObject tdo = new TemperatureDataObject(timestamp, name, temperature);

            enqueue(tdo);
        } catch (Exception e) {
            logger.error("Exception when esp thermometer message: ", e);
        }

    }

}
